@@ -1,5 +1,6 @@
 
 from typing import Callable
+import functools
 
 from .jschema import validate
 
@@ -7,6 +8,7 @@ from .jschema import validate
 def decorator_constructor(getter: Callable, setter: Callable):
     def validator(schema):
         def decorator(func):
+            @functools.wraps(func)
             def wrap(*a, **b):
                 a, b = setter(validate(getter(*a, **b), schema), a, b)
                 return func(*a, **b)
